##  Integration Use Case: Application Rationalization
Application portfolio rationalization is the act of streamlining the existing application portfolio with an explicit goal of improving efficiency, reducing complexity, and lowering the total cost of ownership (TCO) through a myriad of processes. SAP LeanIX stands as the single source of truth for IT data pertaining to business capabilities, applications, IT components, user groups, projects, and providers. Syncing this data to Apptio’s industry-leading cost modeling SaaS solution enables users to broaden their reporting capabilities and dissect reports using different sets of analytics. This provides automated, comprehensive financial reviews and more accurate budget forecasting.
A company in the casino-entertainment industry with nearly $9 billion in global annual revenues synced their SAP LeanIX instance with Apptio to eliminate manual effort and ensure a continuum of accurate data that matches their technology business management (TBM) taxonomy. This led to easy visualization, tracking, and reporting of application costs as they relate to business functions across the enterprise.
For enterprise architects (EAs) working to report up the ladder, and C-level executives examining cost pools across the IT landscape, the integration between Apptio and SAP LeanIX helps the application rationalization process by:
  * Reducing costs through transparency
  * Tethering cost information to application lifecycle data to reduce complexity and improve decision-making
  * Enabling the visualization of various scenarios based on technical fit, functional fit, business criticality, and cost of applications to inform rationalization strategies
  * Surfacing technology dependencies and risks that contain the highest cost ramifications
